@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-pie-item.c,v 1.21 2001/01/16 23:36:03 trow Exp $ */
+/* $Id: guppi-pie-item.c,v 1.26 2001/09/08 05:49:48 trow Exp $ */
 
 /*
  * guppi-pie-item.c
@@ -98,19 +98,7 @@ guppi_pie_item_finalize (GtkObject * obj)
     parent_class->finalize (obj);
 }
 
-/****************************************************************************/
-
-static void
-state_changed (GuppiCanvasItem * gci)
-{
-  guppi_canvas_item_request_update (gci);
-}
-
-static void
-view_changed (GuppiCanvasItem * gci)
-{
-  guppi_canvas_item_request_update (gci);
-}
+/**************************************************************************/
 
 static void
 update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
@@ -121,16 +109,27 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
   GList *iter;
   gint i, i0, i1;
   double sc = guppi_canvas_item_scale (gci);
-  double sc_r, sc_ew;
+  double sc_r, sc_ew, edge_width, base_angle;
   double run_ang;
   gint cx0, cx1, cy0, cy1;
+  GnomeFont *label_font;
+  gboolean show_perc;
 
   guppi_pie_state_slice_bounds (state, &i0, &i1);
-  if (i0 > i1)
+    
+  if (i0 > i1) {
     return;
+  }
+
+  guppi_element_state_get (GUPPI_ELEMENT_STATE (state),
+			   "edge_width", &edge_width,
+			   "label_font", &label_font,
+			   "show_percentage", &show_perc,
+			   "base_angle", &base_angle,
+			   NULL);
 
   sc_r = guppi_pt2px (guppi_pie_view_effective_radius (view) * sc);
-  sc_ew = guppi_pt2px (guppi_pie_state_edge_width (state) * sc);
+  sc_ew = guppi_pt2px (edge_width * sc);
 
   guppi_canvas_item_get_bbox_c (gci, &cx0, &cy0, &cx1, &cy1);
 
@@ -164,8 +163,7 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
   }
 
   /* If necessary, create a list w/ our empty raster text items. */
-  if (guppi_pie_state_show_percentages (state) &&
-      item->edge_percent_templates == NULL) {
+  if (show_perc && item->edge_percent_templates == NULL) {
     for (i = 0; i <= i1 - i0 + 1; ++i)
       item->edge_percent_templates =
 	g_list_prepend (item->edge_percent_templates,
@@ -173,7 +171,7 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
     item->edge_percent_template_count = i1 - i0 + 1;
   }
   
-  run_ang = guppi_pie_state_base_angle (state);
+  run_ang = base_angle;
 
   iter = item->edge_percent_templates;
   for (i = i0; i <= i1; ++i) {
@@ -201,9 +199,8 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
 
     /* Rasterize text for percentages to be shown at the edge
        of the pie slices. */
-    if (guppi_pie_state_show_percentages (state)) {
+    if (show_perc) {
       GuppiRasterText *rt = iter ? GUPPI_RASTER_TEXT (iter->data) : NULL;
-      GnomeFont *font = guppi_pie_state_label_font (state);
       double R, x, y, lab_th;
       gint w = 0, h = 0;
 
@@ -213,7 +210,7 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
 	g_snprintf (buffer, 32, "%d%%", (gint) rint (100 * perc));
 
 	guppi_raster_text_set_text (rt, buffer);
-	guppi_raster_text_set_font (rt, font);
+	guppi_raster_text_set_font (rt, label_font);
 	guppi_raster_text_set_scale (rt, sc);
 
 	if (guppi_raster_text_template (rt)) {
@@ -240,23 +237,32 @@ update (GuppiCanvasItem * gci, double aff[6], ArtSVP * svp, gint flags)
       
     run_ang += th;
   }
+
+  guppi_unref (label_font);
 }
 
 static void
-render (GuppiCanvasItem * gci, GnomeCanvasBuf * buf)
+render (GuppiCanvasItem *gci, GnomeCanvasBuf *buf)
 {
   GuppiPieItem *item = GUPPI_PIE_ITEM (gci);
   GuppiPieState *state = GUPPI_PIE_STATE (guppi_canvas_item_state (gci));
   GList *iter;
   gint i;
+  gboolean show_perc;
+  guint32 label_color, edge_color;
+
+  guppi_element_state_get (GUPPI_ELEMENT_STATE (state),
+			   "show_percentage", &show_perc,
+			   "label_color", &label_color,
+			   "edge_color", &edge_color,
+			   NULL);
 
   /* Render the inside of the slices. */
   iter = item->slice_fill_svp;
   i = 0;
   while (iter) {
     ArtSVP *svp = (ArtSVP *) iter->data;
-    gnome_canvas_render_svp (buf, svp,
-			     guppi_pie_state_slice_color (state, i));
+    gnome_canvas_render_svp (buf, svp, guppi_pie_state_slice_color (state, i));
     iter = g_list_next (iter);
     ++i;
   }
@@ -265,15 +271,15 @@ render (GuppiCanvasItem * gci, GnomeCanvasBuf * buf)
   iter = item->slice_edge_svp;
   while (iter) {
     ArtSVP *svp = (ArtSVP *) iter->data;
-    gnome_canvas_render_svp (buf, svp, guppi_pie_state_edge_color (state));
+    gnome_canvas_render_svp (buf, svp, edge_color);
     iter = g_list_next (iter);
   }
 
   /* Render our percentage labels. */
-  if (guppi_pie_state_show_percentages (state)) {
+  if (show_perc) {
     guint r, g, b, a;
 
-    UINT_TO_RGBA (guppi_pie_state_label_color (state), &r, &g, &b, &a);
+    UINT_TO_RGBA (label_color, &r, &g, &b, &a);
 
     iter = item->edge_percent_templates;
 
@@ -348,8 +354,6 @@ guppi_pie_item_class_init (GuppiPieItemClass * klass)
   object_class->destroy = guppi_pie_item_destroy;
   object_class->finalize = guppi_pie_item_finalize;
 
-  gci_class->state_changed = state_changed;
-  gci_class->view_changed = view_changed;
   gci_class->guppi_update = update;
   gci_class->guppi_render = render;
   gci_class->foreach_class_toolkit = foreach_class_toolkit;
@@ -443,7 +447,10 @@ guppi_pie_item_in_slice (GuppiPieItem * item, gint x, gint y, gint * slice)
   if (pt_theta < 0)
     pt_theta += 2 * M_PI;
 
-  run_ang = guppi_pie_state_base_angle (state);
+  guppi_element_state_get (GUPPI_ELEMENT_STATE (state),
+			   "base_angle", &run_ang,
+			   NULL);
+
   for (i = i0; i <= i1; ++i) {
     double th = 2 * M_PI * guppi_pie_state_slice_percentage (state, i);
     double sc_off = guppi_pie_state_slice_offset (state, i);
@@ -480,4 +487,4 @@ guppi_pie_item_in_slice (GuppiPieItem * item, gint x, gint y, gint * slice)
 }
 
 
-/* $Id: guppi-pie-item.c,v 1.21 2001/01/16 23:36:03 trow Exp $ */
+/* $Id: guppi-pie-item.c,v 1.26 2001/09/08 05:49:48 trow Exp $ */
