@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: jitter.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: jitter.h,v 1.8 2001/11/19 05:40:45 trow Exp $ */
 
 /*
  * jitter.h
@@ -28,8 +28,10 @@
 #ifndef _INC_JITTER_H
 #define _INC_JITTER_H
 
-#include <gnome.h>
-#include <guppi-defs.h>
+/* #include <gnome.h> */
+#include <glib.h>
+
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
@@ -41,4 +43,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_JITTER_H */
 
-/* $Id: jitter.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: jitter.h,v 1.8 2001/11/19 05:40:45 trow Exp $ */
