@@ -1,4 +1,4 @@
-/* $Id: guppi-metrics.h,v 1.9 2001/01/16 23:36:40 trow Exp $ */
+/* $Id: guppi-metrics.h,v 1.10 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-metrics.h
@@ -28,7 +28,7 @@
 
 /* #include <gtk/gtk.h> */
 #include <glib.h>
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
@@ -89,4 +89,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_METRICS_H */
 
-/* $Id: guppi-metrics.h,v 1.9 2001/01/16 23:36:40 trow Exp $ */
+/* $Id: guppi-metrics.h,v 1.10 2001/11/19 05:40:52 trow Exp $ */
