@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-rgb.h,v 1.11 2001/01/16 23:36:40 trow Exp $ */
+/* $Id: guppi-rgb.h,v 1.14 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-rgb.h
@@ -34,7 +34,7 @@
 
 #include <math.h>
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
@@ -65,10 +65,10 @@ BEGIN_GUPPI_DECLS
 #define RGBA_CYAN   RGB_TO_RGBA(RGB_CYAN, 0xff)
 #define RGB_GREY(x) RGB_TO_UINT(x,x,x)
 #define RGBA_GREY(x) RGB_TO_RGBA(RGB_GREY(x), 0xff)
-#define UINT_RGBA_R(x) (((uint)(x))>>24)
-#define UINT_RGBA_G(x) ((((uint)(x))>>16)&0xff)
-#define UINT_RGBA_B(x) ((((uint)(x))>>8)&0xff)
-#define UINT_RGBA_A(x) (((uint)(x))&0xff)
+#define UINT_RGBA_R(x) (((guint)(x))>>24)
+#define UINT_RGBA_G(x) ((((guint)(x))>>16)&0xff)
+#define UINT_RGBA_B(x) ((((guint)(x))>>8)&0xff)
+#define UINT_RGBA_A(x) (((guint)(x))&0xff)
 #define UINT_RGBA_CHANGE_R(x, r) (((x)&(~(0xff<<24)))|(((r)&0xff)<<24))
 #define UINT_RGBA_CHANGE_G(x, g) (((x)&(~(0xff<<16)))|(((g)&0xff)<<16))
 #define UINT_RGBA_CHANGE_B(x, b) (((x)&(~(0xff<<8)))|(((b)&0xff)<<8))
@@ -183,7 +183,8 @@ UINT_TO_RGB((i), ((guchar*)p), ((guchar*)p)+1, ((guchar*)p)+2)
     } \
   } \
 }
-  guint32 guppi_str2color_rgba (const gchar * color_name);
+
+guint32 guppi_str2color_rgba (const gchar *color_name);
 
 void guppi_paint_horiz (GnomeCanvasBuf *, gint x0, gint x1, gint y,
 			guint32 c);
@@ -214,4 +215,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_RGB_H */
 
-/* $Id: guppi-rgb.h,v 1.11 2001/01/16 23:36:40 trow Exp $ */
+/* $Id: guppi-rgb.h,v 1.14 2001/11/19 05:40:52 trow Exp $ */
