@@ -1,4 +1,4 @@
-/* $Id: guppi-timer.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-timer.h,v 1.8 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-timer.h
@@ -26,9 +26,10 @@
 #ifndef _INC_GUPPI_TIMER_H
 #define _INC_GUPPI_TIMER_H
 
-#include <gtk/gtk.h>
+/* #include <gtk/gtk.h> */
+#include <glib.h>
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -43,4 +44,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_TIMER_H */
 
-/* $Id: guppi-timer.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
+/* $Id: guppi-timer.h,v 1.8 2001/11/19 05:40:52 trow Exp $ */
