@@ -1,4 +1,4 @@
-/* $Id: guppi-useful.h,v 1.20 2001/04/14 01:19:21 trow Exp $ */
+/* $Id: guppi-useful.h,v 1.22 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-useful.h
@@ -27,38 +27,30 @@
 #ifndef _INC_GUPPI_USEFUL_H
 #define _INC_GUPPI_USEFUL_H
 
-#include <guppi-convenient.h>
-#include <guppi-debug.h>
-#include <guppi-dialogs.h>
-#include <guppi-defaults.h>
-#include <guppi-enums.h>
-#include <guppi-exit.h>
-#include <guppi-file.h>
-#include <guppi-guile.h>
-#include <guppi-matrix.h>
-#include <guppi-metrics.h>
-#include <guppi-paths.h>
-#include <guppi-plug-in-spec.h>
-#include <guppi-plug-in.h>
-#include <guppi-progress.h>
-#include <guppi-rgb.h>
-#include <guppi-scripting.h>
-#include <guppi-splash.h>
-#include <guppi-stream.h>
-#include <guppi-stream-preview.h>
-#include <guppi-string.h>
-#include <guppi-timer.h>
-#include <guppi-version.h>
+#include  "guppi-convenient.h"
+#include  "guppi-debug.h"
+#include  "guppi-dialogs.h"
+#include  "guppi-defaults.h"
+#include  "guppi-enums.h"
+#include  "guppi-exit.h"
+#include  "guppi-file.h"
+#include  "guppi-guile.h"
+#include  "guppi-matrix.h"
+#include  "guppi-metrics.h"
+#include  "guppi-paths.h"
+#include  "guppi-plug-in-spec.h"
+#include  "guppi-plug-in.h"
+#include  "guppi-progress.h"
+#include  "guppi-rgb.h"
+#include  "guppi-scripting.h"
+#include  "guppi-stream.h"
+#include  "guppi-stream-preview.h"
+#include  "guppi-string.h"
+#include  "guppi-timer.h"
+#include  "guppi-version.h"
 
-#include <guppi-defs.h>
-
-BEGIN_GUPPI_DECLS
-
-void guppi_useful_init (void);
-void guppi_useful_init_without_guile (void);
-
-END_GUPPI_DECLS
+#include  "guppi-useful-init.h"
 
 #endif /* _INC_GUPPI_USEFUL_H */
 
-/* $Id: guppi-useful.h,v 1.20 2001/04/14 01:19:21 trow Exp $ */
+/* $Id: guppi-useful.h,v 1.22 2001/11/19 05:40:52 trow Exp $ */
